@@ -2,18 +2,19 @@
 #
 # zzz.R
 #
-# Written by John Hughes <hughesj@umn.edu>.
+# Written by John Hughes <jhughesjr@gmail.com>.
 #
-# Last Modified 01/16/15
+# Last Modified 07/03/16
 # Licensed under the GNU General Public License version 2 (June, 1991)
 #
 # Part of the R/batchmeans package
 #
-# .onLoad is run when the package is loaded with library(batchmeans)
-#
 ######################################################################
 
 #' @import utils
+#' @importFrom graphics lines
+#' @importFrom graphics plot
+#' @importFrom stats acf
 
 .onAttach = function(libname, pkgname)
 {
@@ -22,8 +23,8 @@
     msg = paste(temp$Package, ": ", temp$Title, "\n", "Version ", temp$Version,
                 " created on ", temp$Date, ".\n", sep = "")
     msg = paste(msg,
-"copyright (c) 2012-15, Murali Haran, Penn State University\n",
-"                    John Hughes, University of Minnesota\n", sep = "")
+"copyright (c) 2012-2016, Murali Haran, Penn State University\n",
+"                         John Hughes, University of Colorado Denver\n", sep = "")
     msg = paste(msg, 'For citation information, type citation("batchmeans").\n', sep = "")
     msg = paste(msg, 'Type help(package = batchmeans) to get started.\n', sep = "")
     packageStartupMessage(msg)
